<img src='https://jwcarr.github.io/eyekit/images/logo.png' width='300'>

Eyekit is a Python package for doing open, reproducible science on reading behavior. Eyekit is entirely independent of any particular eyetracker hardware, presentation software, or data formats, and has a minimal set of dependencies. It has an object-oriented style that defines two core objects – the TextBlock and the FixationSequence – that you bring into contact with a bit of coding. Eyekit is currently in the pre-alpha stage and is licensed under the terms of the MIT License.

**[A guide to Eyekit and full documentation is available here](https://jwcarr.github.io/eyekit/)**
